Desktopography command line
===========================

see http://www.desktopography.net

Usage
-----

.. code-block:: console

    $ pip install desktopography
    $ desktopography -h

TODO
----

- Add more verbose documentation and docstrings